#
# spec file for package python-joserfc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-joserfc
Version:        1.1.0
Release:        1.1
Summary:        The ultimate Python library for JOSE RFCs
License:        BSD-3-Clause
URL:            https://github.com/authlib/joserfc
Source:         https://files.pythonhosted.org/packages/source/j/joserfc/joserfc-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module pycryptodome}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
Requires:       python-cryptography
Suggests:       python-pycryptodome
BuildArch:      noarch
%python_subpackages

%description
The ultimate Python library for JOSE RFCs, including JWS, JWE, JWK, JWA, JWT

%prep
%autosetup -p1 -n joserfc-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/joserfc
%{python_sitelib}/joserfc-%{version}.dist-info

%changelog
* Wed Jun 11 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.1.0
  * Use ECKey.binding.register_curve to register new supported curves
  * Add __eq__ for Key and KeySet
  * Use InvalidHeaderValueError in registry header validation
  * Prevent from Base64 Malleability
  * Export import_key and generate_key methods
  * Use import as for prioritize the modules for editors
  * Use UnsupportedAlgorithmError instead of ValueError in JWS/JWE registry
  * Use MissingKeyTypeError, InvalidKeyIdError errors
  * Allow jwt.encode passing encoder_cls and jwt.decode passing decoder_cls
  * Use correct types for encoder_cls and decoder_cls parameters
  * Respect RFC6749 character set in error descriptions
  * Add KeyBase and GuestProtocol to __all__
  * Update header validation raised errors
  * Add "none" algorithm for JWS
  * Cleanup joserfc.util
  * Cleanup useless code in joserfc.util
  * Update default value type hints for BaseKey.get method, #52
  * Raise MissingKeyError when import empty key set. #35
  * Remove useless catching binascii.Error
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.0:
  * Fix type hints for strict mode.
* Mon Jun 17 2024 Dirk Müller <dmueller@suse.com>
- update to 0.12.0:
  * Limit DEF decompress size to 250k bytes.
  * Fix claims validation, , via :issue:`23`.
  * Remove validating typ header with jwt.decode method.
  * jwe.decrypt_json allows to verify only one recipient.
  * Prevent OctKey to import ssh-dss.
  * Deprecate use of string and bytes as key.
* Tue May 14 2024 Dirk Müller <dmueller@suse.com>
- update to 0.10.0:
  * Change jwt.encode and jwt.decode to use JWS by default
* Wed Mar 27 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Mar  1 2024 Markéta Machová <mmachova@suse.com>
- Initial packaging (v0.9.0), needed by python-moto
